summaryrefslogtreecommitdiffstats
path: root/src/H5S.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>1998-07-07 19:10:01 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>1998-07-07 19:10:01 (GMT)
commita67faf317232fc0cc5ea7c4074ae879e51c04636 (patch)
tree3ac9a3a18a64a5ddb4ea284f90932eded8aad5dd /src/H5S.c
parent27fa4c698f3d07e5e9e7655943526bbdf2b4a2ec (diff)
downloadhdf5-a67faf317232fc0cc5ea7c4074ae879e51c04636.zip
hdf5-a67faf317232fc0cc5ea7c4074ae879e51c04636.tar.gz
hdf5-a67faf317232fc0cc5ea7c4074ae879e51c04636.tar.bz2
[svn-r458] Changed H5Sget_npoints call to H5Sextent_npoints and H5Sselect_npoints calls.
Diffstat (limited to 'src/H5S.c')
-rw-r--r--src/H5S.c25
1 files changed, 13 insertions, 12 deletions
diff --git a/src/H5S.c b/src/H5S.c
index 7ebf490..3899ee8 100644
--- a/src/H5S.c
+++ b/src/H5S.c
@@ -427,11 +427,11 @@ H5S_t * H5S_copy(const H5S_t *src)
}
/*-------------------------------------------------------------------------
- * Function: H5Sget_npoints
+ * Function: H5Sextent_npoints
*
* Purpose: Determines how many data points a data set has.
*
- * Return: Success: Number of data points in the data set.
+ * Return: Success: Number of data points in the dataset.
*
* Failure: 0
*
@@ -439,34 +439,35 @@ H5S_t * H5S_copy(const H5S_t *src)
* Tuesday, December 9, 1997
*
* Modifications:
+ * Changed Name - QAK 7/7/98
*
*-------------------------------------------------------------------------
*/
hsize_t
-H5Sget_npoints (hid_t space_id)
+H5Sextent_npoints (hid_t space_id)
{
H5S_t *ds = NULL;
hsize_t ret_value = 0;
- FUNC_ENTER(H5Sget_npoints, 0);
+ FUNC_ENTER(H5Sextent_npoints, 0);
H5TRACE1("h","i",space_id);
/* Check args */
if (H5_DATASPACE != H5I_group(space_id) || NULL == (ds = H5I_object(space_id))) {
HRETURN_ERROR(H5E_ARGS, H5E_BADTYPE, 0, "not a data space");
}
- ret_value = H5S_get_npoints(ds);
+ ret_value = H5S_extent_npoints(ds);
FUNC_LEAVE(ret_value);
}
/*-------------------------------------------------------------------------
- * Function: H5S_get_npoints
+ * Function: H5S_extent_npoints
*
* Purpose: Determines how many data points a data set has.
*
* Return: Success: Number of data points in the data set.
*
* Failure: 0
*
@@ -474,16 +475,17 @@ H5Sget_npoints (hid_t space_id)
* Tuesday, December 9, 1997
*
* Modifications:
+ * Changed Name - QAK 7/7/98
*
*-------------------------------------------------------------------------
*/
hsize_t
-H5S_get_npoints(const H5S_t *ds)
+H5S_extent_npoints(const H5S_t *ds)
{
hsize_t ret_value = 0;
intn i;
- FUNC_ENTER(H5S_get_npoints, 0);
+ FUNC_ENTER(H5S_extent_npoints, 0);
/* check args */
assert(ds);
@@ -1372,4 +1374,3 @@ done:
}
FUNC_LEAVE(ret_value);
}
-
@@ -427,11 +427,11 @@ H5S_t * H5S_copy(const H5S_t *src)
*
- * Purpose: Determines how many data points a data set has.
+ * Purpose: Determines how many data points a dataset extent has.
*
@@ -439,34 +439,35 @@ H5S_t * H5S_copy(const H5S_t *src)
*
- * Purpose: Determines how many data points a data set has.
+ * Purpose: Determines how many data points a dataset extent has.
*
@@ -439,34 +439,35 @@ H5S_t * H5S_copy(const H5S_t *src)
*
- * Return: Success: Number of data points in the data set.
+ * Return: Success: Number of data points in the dataset extent.
*
* Failure: 0